@@ -1,29 +1,28 @@
-from __future__ import unicode_literals
-from __future__ import absolute_import, division, print_function
-
-import logging
 import os
-import re
+import string
+import logging
 from typing import Optional, List, Dict, Any
 
-import papis.config
 import click
+
+import papis.config
 import papis.importer
 import papis.filetype
 import papis.document
+import papis.format
 
 logger = logging.getLogger("bibtex")  # type: logging.Logger
 
 bibtex_types = [
-  "article", "book", "booklet", "conference", "inbook", "incollection",
-  "inproceedings", "manual", "mastersthesis", "misc", "phdthesis",
-  "proceedings", "techreport", "unpublished"
+    "article", "book", "booklet", "conference", "inbook", "incollection",
+    "inproceedings", "manual", "mastersthesis", "misc", "phdthesis",
+    "proceedings", "techreport", "unpublished"
 ] + papis.config.getlist('extra-bibtex-types')  # type: List[str]
 
 bibtex_type_converter = {
-  "conferencePaper": "inproceedings",
-  "journalArticle": "article",
-  "journal": "article"
+    "conferencePaper": "inproceedings",
+    "journalArticle": "article",
+    "journal": "article"
 }  # type: Dict[str, str]
 
 bibtex_keys = [
@@ -38,7 +37,7 @@ bibtex_keys = [
     "mainsubtitle", "maintitle", "maintitleaddon", "month", "note",
     "number", "organization", "origlanguage", "pages", "pagetotal", "part",
     "publisher", "pubstate", "school", "series", "subtitle", "title",
-    "translator", "type", "titleaddon", "url", "urldate", "venue", "version",
+    "translator", "titleaddon", "url", "urldate", "venue", "version",
     "volume", "volumes", "year",
 ] + papis.config.getlist('extra-bibtex-keys')  # type: List[str]
 
@@ -65,8 +64,8 @@ class Importer(papis.importer.Importer):
 
     @classmethod
     def match(cls, uri: str) -> Optional[papis.importer.Importer]:
-        if (not os.path.exists(uri) or os.path.isdir(uri) or
-                papis.filetype.get_document_extension(uri) == 'pdf'):
+        if (not os.path.exists(uri) or os.path.isdir(uri)
+                or papis.filetype.get_document_extension(uri) == 'pdf'):
             return None
         importer = Importer(uri=uri)
         importer.fetch()
@@ -74,13 +73,13 @@ class Importer(papis.importer.Importer):
 
     @papis.importer.cache
     def fetch(self: papis.importer.Importer) -> Any:
-        self.logger.info("Reading input file = %s" % self.uri)
+        self.logger.info("Reading input file = '%s'", self.uri)
         try:
             bib_data = bibtex_to_dict(self.uri)
             if len(bib_data) > 1:
                 self.logger.warning(
-                    'Your bibtex file contains more than one entry,'
-                    ' I will be taking the first entry')
+                    'The bibtex file contains more than one entry, '
+                    'only taking the first entry')
             if bib_data:
                 self.ctx.data = bib_data[0]
         except Exception as e:
@@ -101,42 +100,35 @@ def explorer(ctx: click.core.Context, bibfile: str) -> None:
 
     """
     logger = logging.getLogger('explore:bibtex')
-    logger.info('Reading in bibtex file {}'.format(bibfile))
+    logger.info("Reading in bibtex file '%s'", bibfile)
+
     docs = [
         papis.document.from_data(d)
         for d in bibtex_to_dict(bibfile)]
     ctx.obj['documents'] += docs
-    logger.info('{} documents found'.format(len(docs)))
+
+    logger.info('%d documents found', len(docs))
 
 
 def bibtexparser_entry_to_papis(entry: Dict[str, str]) -> Dict[str, str]:
-    """Convert keys of a bib entry in bibtexparser format to papis compatible
-    format.
+    """Convert keys of a bib entry in bibtexparser format to papis
+    compatible format.
 
     :param entry: Dictionary with keys of bibtexparser format.
     :type  entry: dict
     :returns: Dictionary with keys of papis format.
 
     """
-    from bibtexparser.customization import splitname
-
-    def to_author_list(authors: str) -> List[Dict[str, str]]:
-        author_list = []
-        for author in re.split(r"\s+and\s+", authors):
-            parts = splitname(author)
-            given = " ".join(parts["first"])
-            family = " ".join(parts["von"] + parts["last"] + parts["jr"])
-
-            author_list.append(dict(family=family, given=given))
-
-        return author_list
 
     _k = papis.document.KeyConversionPair
     key_conversion = [
         _k("ID", [{"key": "ref", "action": None}]),
         _k("ENTRYTYPE", [{"key": "type", "action": None}]),
         _k("link", [{"key": "url", "action": None}]),
-        _k("author", [{"key": "author_list", "action": to_author_list}]),
+        _k("author", [{
+            "key": "author_list", "action":
+                lambda author: papis.document.split_authors_name([author])
+            }]),
     ]
 
     result = papis.document.keyconversion_to_data(
@@ -169,10 +161,9 @@ def bibtex_to_dict(bibtex: str) -> List[Dict[str, str]]:
 
     # bibtexparser has too many debug messages to be useful
     logging.getLogger("bibtexparser.bparser").setLevel(logging.WARNING)
-    global logger
     if os.path.exists(bibtex):
         with open(bibtex) as fd:
-            logger.debug("Reading in file %s" % bibtex)
+            logger.debug("Reading in file '%s'", bibtex)
             text = fd.read()
     else:
         text = bibtex
@@ -181,12 +172,54 @@ def bibtex_to_dict(bibtex: str) -> List[Dict[str, str]]:
     return [bibtexparser_entry_to_papis(entry) for entry in entries]
 
 
+def ref_cleanup(ref: str) -> str:
+    """
+    Function to cleanup references to be acceptable for latex
+    """
+    import slugify
+    allowed_characters = r'([^a-zA-Z0-9._]+|(?<!\\)[._])'
+    return string.capwords(str(slugify.slugify(
+               ref,
+               lowercase=False,
+               word_boundary=False,
+               separator=" ",
+               regex_pattern=allowed_characters))).replace(" ", "")
+
+
+def create_reference(doc: Dict[str, Any]) -> str:
+    """
+    Try to create a sane reference for the document
+    """
+    ref = ""
+    # Check first if the paper has a reference
+    if doc.get("ref"):
+        return str(doc["ref"])
+    elif papis.config.get('ref-format'):
+        try:
+            ref = papis.format.format(papis.config.getstring("ref-format"),
+                                      doc)
+        except Exception as e:
+            logger.error(e)
+            ref = ""
+
+    logger.debug("Generated 'ref = %s'", ref)
+    if not ref:
+        if doc.get('doi'):
+            ref = doc['doi']
+        else:
+            # Just try to get something out of the data
+            ref = "{:.30}".format(
+                " ".join(string.capwords(str(d)) for d in doc.values()))
+
+    return ref_cleanup(ref)
+
+
 def to_bibtex(document: papis.document.Document) -> str:
     """Create a bibtex string from document's information
 
     :param document: Papis document
     :type  document: Document
-    :returns: String containing bibtex formating
+    :returns: String containing bibtex formatting
     :rtype:  str
 
     """
@@ -203,40 +236,17 @@ def to_bibtex(document: papis.document.Document) -> str:
     if not bibtex_type:
         bibtex_type = "article"
 
-    # REFERENCE BUILDING
-    if document.has("ref"):
-        ref = document["ref"]
-    elif papis.config.get('ref-format'):
-        try:
-            ref = papis.document.format_doc(
-                papis.config.getstring("ref-format"),
-                document
-            ).replace(" ", "")
-        except Exception as e:
-            logger.error(e)
-            ref = None
-
-    logger.debug("generated ref=%s" % ref)
-    if not ref:
-        if document.has('doi'):
-            ref = document['doi']
-        else:
-            folder = document.get_main_folder()
-            if folder:
-                ref = os.path.basename(folder)
-            else:
-                ref = 'noreference'
-
-    ref = re.sub(r'[;,()\/{}\[\]]', '', ref)
-    logger.debug("Used ref=%s" % ref)
+    ref = create_reference(document)
+    logger.debug("Used 'ref = %s'", ref)
 
     bibtex_string += "@{type}{{{ref},\n".format(type=bibtex_type, ref=ref)
+    bibtex_keyval_fmt = "  %s = {%s},\n"
     for bibKey in list(document.keys()):
         if bibKey in bibtex_key_converter:
             new_bibkey = bibtex_key_converter[bibKey]
             document[new_bibkey] = document[bibKey]
     for bibKey in sorted(document.keys()):
-        logger.debug('%s : %s' % (bibKey, document[bibKey]))
+        logger.debug("Bibtex entry: '%s: %s'", bibKey, document[bibKey])
         if bibKey in bibtex_keys:
             value = str(document[bibKey])
             if not papis.config.getboolean('bibtex-unicode'):
@@ -244,17 +254,22 @@ def to_bibtex(document: papis.document.Document) -> str:
             if bibKey == 'journal':
                 journal_key = papis.config.getstring('bibtex-journal-key')
                 if journal_key in document.keys():
-                    bibtex_string += "  %s = {%s},\n" % (
+                    bibtex_string += bibtex_keyval_fmt % (
                         'journal',
                         unicode_to_latex(str(document[journal_key]))
                     )
                 elif journal_key not in document.keys():
                     logger.warning(
-                        "Key '{0}' is not present for ref={1}"
-                        .format(journal_key, document["ref"]))
-                    bibtex_string += "  %s = {%s},\n" % ('journal', value)
+                            "Key '%s' is not present for ref '%s'",
+                            journal_key, document["ref"])
+                    bibtex_string += bibtex_keyval_fmt % ('journal', value)
             else:
-                bibtex_string += "  %s = {%s},\n" % (bibKey, value)
+                bibtex_string += bibtex_keyval_fmt % (bibKey, value)
+    # Handle file for zotero exporting
+    if (papis.config.getboolean("bibtex-export-zotero-file")
+            and len(document.get_files())):
+        bibtex_string += bibtex_keyval_fmt % ("file",
+                                              ";".join(document.get_files()))
     bibtex_string += "}\n"
     return bibtex_string
 
