@@ -2,7 +2,7 @@
 The add command is one of the central commands of the papis command line
 interface. It is a very versatile command with a fair amount of options.
 
-There are also customization settings availabe for this command, check out
+There are also customization settings available for this command, check out
 the :ref:`configuration page <add-command-options>` for add.
 
 Examples
@@ -41,7 +41,7 @@ Examples
     .. code::
 
         papis -l machine-learning add \\
-            --from url https://arxiv.org/abs/1712.03134
+            --from arxiv https://arxiv.org/abs/1712.03134
 
 - If you do not want copy the original pdfs into the library, you can
   also tell papis to just create a link to them, for example
@@ -71,6 +71,7 @@ Examples
     .. code::
 
         papis add journals.aps.org/prl/abstract/10.1103/PhysRevLett.123.156401
+        papis add https://arxiv.org/abs/1712.03134
 
 
 Examples in python
@@ -87,19 +88,13 @@ Cli
     :prog: papis add
 
 """
-from typing import List, Any, Optional, Dict, Tuple
-import logging
-from string import ascii_lowercase
 import os
 import re
-import tempfile
-import hashlib
-import shutil
+import logging
+from typing import List, Any, Optional, Dict, Tuple
 
 import click
-import colorama
 
-import time
 import papis.api
 import papis.pick
 import papis.utils
@@ -112,6 +107,7 @@ import papis.cli
 import papis.strings
 import papis.downloaders
 import papis.git
+import papis.format
 
 logger = logging.getLogger('add')  # type: logging.Logger
 
@@ -128,8 +124,9 @@ class FromFolderImporter(papis.importer.Importer):
         return FromFolderImporter(uri=uri) if os.path.isdir(uri) else None
 
     def fetch(self) -> None:
+        self.logger.info("Importing from folder '%s'", self.uri)
+
         doc = papis.document.from_folder(self.uri)
-        self.logger.info('importing from folder {0}'.format(self.uri))
         self.ctx.data = papis.document.to_dict(doc)
         self.ctx.files = doc.get_files()
 
@@ -188,15 +185,12 @@ def get_file_name(
         file_name_opt = os.path.basename(original_filepath)
 
     # Get a file name from the format `add-file-name`
-    file_name_base = papis.document.format_doc(
-        file_name_opt,
-        papis.document.from_data(data)
-    )
+    file_name_base = papis.format.format(file_name_opt,
+                                         papis.document.from_data(data))
 
     if len(file_name_base) > basename_limit:
         logger.warning(
-            "Shortening the name {0} for portability".format(file_name_base)
-        )
+            "Shortening the file name '%s' for portability", file_name_base)
         file_name_base = file_name_base[0:basename_limit]
 
     # Remove extension from file_name_base, if any
@@ -236,11 +230,12 @@ def get_hash_folder(data: Dict[str, Any], document_paths: List[str]) -> str:
         with open(docpath, 'rb') as fd:
             document_strings += fd.read(2000)
 
+    import hashlib
     md5 = hashlib.md5(
-        ''.join(document_paths).encode() +
-        str(data).encode() +
-        str(random.random()).encode() +
-        document_strings
+        ''.join(document_paths).encode()
+        + str(data).encode()
+        + str(random.random()).encode()
+        + document_strings
     ).hexdigest()
 
     result = md5 + author
@@ -249,8 +244,7 @@ def get_hash_folder(data: Dict[str, Any], document_paths: List[str]) -> str:
     return result
 
 
-def run(
-        paths: List[str],
+def run(paths: List[str],
         data: Dict[str, Any] = dict(),
         folder_name: Optional[str] = None,
         file_name: Optional[str] = None,
@@ -275,19 +269,21 @@ def run(
     :param subfolder: Folder within the library where the document's folder
         should be stored.
     :type  subfolder: str
-    :param confirm: Wether or not to ask user for confirmation before adding.
+    :param confirm: Whether or not to ask user for confirmation before adding.
     :type  confirm: bool
-    :param open_file: Wether or not to ask user for opening file before adding.
+    :param open_file: Whether or not to ask the user for opening the file
+        before adding.
     :type  open_file: bool
-    :param edit: Wether or not to ask user for editing the infor file
+    :param edit: Whether or not to ask user for editing the info file
         before adding.
     :type  edit: bool
-    :param git: Wether or not to ask user for committing before adding,
+    :param git: Whether or not to ask user for committing before adding,
         in the case of course that the library is a git repository.
     :type  git: bool
     """
-
+    import tempfile
     logger = logging.getLogger('add:run')
+
     # The folder name of the new document that will be created
     out_folder_name = None
     # The real paths of the documents to be added
@@ -313,7 +309,7 @@ def run(
         logger.info("Got an automatic folder name")
     else:
         temp_doc = papis.document.Document(data=data)
-        out_folder_name = papis.document.format_doc(folder_name, temp_doc)
+        out_folder_name = papis.format.format(folder_name, temp_doc)
         out_folder_name = papis.utils.clean_document_name(out_folder_name)
         del temp_doc
 
@@ -324,11 +320,12 @@ def run(
             subfolder or '',
             out_folder_name))
 
-    logger.info("The folder name is {0}".format(out_folder_name))
-    logger.debug("Folder path: {0}".format(out_folder_path))
-    logger.debug("File(s): {0}".format(in_documents_paths))
+    logger.info("The folder name is '%s'", out_folder_name)
+    logger.debug("Folder path: '%s'", out_folder_path)
+    logger.debug("File(s): %s", in_documents_paths)
 
     # First prepare everything in the temporary directory
+    from string import ascii_lowercase
     g = papis.utils.create_identifier(ascii_lowercase)
     string_append = ''
     if file_name is not None:  # Use args if set
@@ -353,16 +350,22 @@ def run(
         if link:
             in_file_abspath = os.path.abspath(in_file_path)
             logger.debug(
-                "[SYMLINK] '%s' to '%s'" %
-                (in_file_abspath, tmp_end_filepath))
+                "[SYMLINK] '%s' to '%s'", in_file_abspath, tmp_end_filepath)
             os.symlink(in_file_abspath, tmp_end_filepath)
         else:
             logger.debug(
-                "[CP] '%s' to '%s'" %
-                (in_file_path, tmp_end_filepath))
+                "[CP] '%s' to '%s'", in_file_path, tmp_end_filepath)
+
+            import shutil
             shutil.copy(in_file_path, tmp_end_filepath)
 
     data['files'] = new_file_list
+
+    # reference building
+    if data.get('ref') is None:
+        data['ref'] = papis.bibtex.create_reference(data)
+        logger.info("Created reference '%s'", data['ref'])
+
     tmp_document.update(data)
     tmp_document.save()
 
@@ -381,18 +384,12 @@ def run(
     except IndexError:
         logger.info("No document matching found already in the library")
     else:
+        logger.warning("{c.Fore.RED}DUPLICATION WARNING{c.Style.RESET_ALL}")
         logger.warning(
-            colorama.Fore.RED +
-            "DUPLICATION WARNING" +
-            colorama.Style.RESET_ALL)
+            "A document in the library seems to match the added one.")
         logger.warning(
-            "The document beneath is in your library and it seems to match")
-        logger.warning(
-            "the one that you're trying to add, "
-            "I will prompt you for confirmation")
-        logger.warning(
-            "(Hint) Use the update command if you just want to update"
-            " the info.")
+            "(Hint) Use the 'papis update' command to just update the info.")
+
         papis.tui.utils.text_area(
             'The following document is already in your library',
             papis.document.dump(found_document),
@@ -408,9 +405,8 @@ def run(
             return
 
     logger.info(
-        "[MV] '%s' to '%s'" %
-        (tmp_document.get_main_folder(), out_folder_path)
-    )
+        "[MV] '%s' to '%s'", tmp_document.get_main_folder(), out_folder_path)
+
     # This also sets the folder of tmp_document
     papis.document.move(tmp_document, out_folder_path)
     papis.database.get().add(tmp_document)
@@ -546,13 +542,11 @@ def cli(
             logger.exception(e)
 
     if matching_importers:
-        logger.info('There are {0} possible matchings'
-                    .format(len(matching_importers)))
+        logger.info('There are %d possible matchings', len(matching_importers))
 
         for importer in matching_importers:
             if importer.ctx.data:
-                logger.info('Merging data from importer {0}'
-                            .format(importer.name))
+                logger.info('Merging data from importer %s', importer.name)
                 if batch:
                     ctx.data.update(importer.ctx.data)
                 else:
@@ -561,8 +555,9 @@ def cli(
                         importer.ctx.data,
                         str(importer))
             if importer.ctx.files:
-                logger.info('Got files {0} from importer {1}'
-                            .format(importer.ctx.files, importer.name))
+                logger.info(
+                        "Got files %s from importer '%s'",
+                        importer.ctx.files, importer.name)
                 for f in importer.ctx.files:
                     papis.utils.open_file(f)
                     _msg = "Use this file? (from {0})".format(importer.name)
@@ -570,10 +565,11 @@ def cli(
                         ctx.files.append(f)
 
     if not ctx:
-        logger.error('there is nothing to be added')
+        logger.error('There is nothing to be added')
         return
 
     if papis.config.getboolean("time-stamp"):
+        import time
         ctx.data['time-added'] = time.strftime(papis.strings.time_format)
 
     return run(
