@@ -7,8 +7,14 @@ Cli
 .. click:: papis.commands.edit:cli
     :prog: papis edit
 """
-import papis
 import os
+import logging
+from typing import Optional
+
+import click
+
+import papis
+import papis.hooks
 import papis.api
 import papis.pick
 import papis.document
@@ -16,24 +22,30 @@ import papis.utils
 import papis.config
 import papis.database
 import papis.cli
-import click
-import logging
 import papis.strings
 import papis.git
-
-from typing import Optional
+import papis.format
 
 
 def run(document: papis.document.Document,
         wait: bool = True,
         git: bool = False) -> None:
-    database = papis.database.get()
+    logger = logging.getLogger('run:edit')
     info_file_path = document.get_info_file()
     if not info_file_path:
         raise Exception(papis.strings.no_folder_attached_to_document)
+    _old_dict = papis.document.to_dict(document)
     papis.utils.general_open(info_file_path, "editor", wait=wait)
     document.load()
-    database.update(document)
+    _new_dict = papis.document.to_dict(document)
+
+    # If nothing changed there is nothing else to be done
+    if _old_dict == _new_dict:
+        logger.debug("old and new are equal, doing nothing")
+        return
+
+    papis.database.get().update(document)
+    papis.hooks.run("on_edit_done")
     if git:
         papis.git.add_and_commit_resource(
             str(document.get_main_folder()),
@@ -42,6 +54,51 @@ def run(document: papis.document.Document,
                 papis.document.describe(document)))
 
 
+def create_notes(document: papis.document.Document,
+                 notes_path: str) -> None:
+
+    templ_path = os.path.expanduser(papis.config.getstring("notes-template"))
+    templ_out = ""
+
+    if os.path.exists(templ_path):
+        with open(templ_path, 'r') as f:
+            templ_src = f.read()
+            templ_out = papis.format.format(templ_src, document)
+
+    with open(notes_path, 'w+') as f:
+        f.write(templ_out)
+
+
+def edit_notes(document: papis.document.Document,
+               git: bool = False) -> None:
+    logger = logging.getLogger('edit:notes')
+    logger.debug("Editing notes")
+
+    db = papis.database.get()
+    if not document.has("notes"):
+        notes_name = papis.config.getstring("notes-name")
+        document["notes"] = papis.format.format(notes_name, document)
+        document.save()
+        db.update(document)
+
+    notes_path = os.path.join(
+        str(document.get_main_folder()),
+        document["notes"]
+    )
+
+    if not os.path.exists(notes_path):
+        logger.debug("Creating '%s'", notes_path)
+        create_notes(document, notes_path)
+
+    papis.api.edit_file(notes_path)
+    if git:
+        papis.git.add_and_commit_resource(
+            str(document.get_main_folder()),
+            str(document.get_info_file()),
+            "Update notes for '{0}'".format(
+                papis.document.describe(document)))
+
+
 @click.command("edit")
 @click.help_option('-h', '--help')
 @papis.cli.query_option()
@@ -92,30 +149,7 @@ def cli(query: str,
 
     for document in documents:
         if notes:
-            logger.debug("Editing notes")
-            if not document.has("notes"):
-                logger.warning(
-                    "The document selected has no notes attached, \n"
-                    "creating a notes files"
-                )
-                document["notes"] = papis.config.getstring("notes-name")
-                document.save()
-            notes_path = os.path.join(
-                str(document.get_main_folder()),
-                document["notes"]
-            )
-
-            if not os.path.exists(notes_path):
-                logger.info("Creating {0}".format(notes_path))
-                open(notes_path, "w+").close()
-
-            papis.api.edit_file(notes_path)
-            if git:
-                papis.git.add_and_commit_resource(
-                    str(document.get_main_folder()),
-                    str(document.get_info_file()),
-                    "Update notes for '{0}'".format(
-                        papis.document.describe(document)))
+            edit_notes(document, git=git)
 
         else:
             run(document, git=git)
