@@ -32,25 +32,33 @@ or export all of them
   ``info.yaml`` file, the linked documents and a ``bibtex`` file for
   sharing with other people.
 
+.. note::
+
+    Every document exported also comes with the key `_papis_local_folder`
+    associated that points to the full local folder path where the document
+    is stored in the file system. This is done for the convenience of third
+    party apps.
+
 
 Cli
 ^^^
 .. click:: papis.commands.export:cli
     :prog: papis export
 """
-import papis
 import os
-import shutil
+import logging
+from typing import List, Optional
+
+import click
+
+import papis
 import papis.utils
 import papis.document
-import click
 import papis.cli
 import papis.api
 import papis.database
 import papis.strings
-import logging
 import papis.plugin
-from typing import List, Optional
 
 logger = logging.getLogger('cli:export')
 
@@ -63,12 +71,12 @@ def _extension_name() -> str:
     return "papis.exporter"
 
 
-def run(documents: List[papis.document.Document], to_format: str,) -> str:
+def run(documents: List[papis.document.Document], to_format: str) -> str:
     """
     Exports several documents into something else.
 
-    :param document: A ist of papis document
-    :type  document: [papis.document.Document]
+    :param documents: A list of papis documents
+    :type  documents: [papis.document.Document]
     :param to_format: what format to use
     :type  to_format: str
     """
@@ -116,7 +124,7 @@ def cli(query: str,
         documents = papis.database.get().query(query)
 
     if fmt and folder:
-        logger.warning("Only --folder flag will be considered")
+        logger.warning("Only --folder flag will be considered (--fmt ignored)")
 
     if not documents:
         logger.warning(papis.strings.no_documents_retrieved_message)
@@ -130,11 +138,16 @@ def cli(query: str,
     if sort_field:
         documents = papis.document.sort(documents, sort_field, sort_reverse)
 
+    # Get the local folder of the document so that third-party apps
+    # can actually go to the folder without checking with papis
+    for d in documents:
+        d["_papis_local_folder"] = d.get_main_folder()
+
     ret_string = run(documents, to_format=fmt)
 
     if ret_string is not None and not folder:
         if out is not None:
-            logger.info("Dumping to {0}".format(out))
+            logger.info("Dumping to '%s'", out)
             with open(out, 'a+') as fd:
                 fd.write(ret_string)
         else:
@@ -142,6 +155,7 @@ def cli(query: str,
             print(ret_string)
         return
 
+    import shutil
     for document in documents:
         if folder:
             _doc_folder = document.get_main_folder()
@@ -151,9 +165,9 @@ def cli(query: str,
                 raise Exception(papis.strings.no_folder_attached_to_document)
             if not len(documents) == 1:
                 outdir = os.path.join(out, _doc_folder_name)
-            logger.info("Exporting doc {0} to {1}".format(
-                papis.document.describe(document), outdir
-            ))
+            logger.info(
+                    "Exporting doc '%s' to '%s'",
+                    papis.document.describe(document), outdir)
             shutil.copytree(_doc_folder, outdir)
 
 
@@ -187,8 +201,7 @@ def explorer(ctx: click.Context, fmt: str, out: str) -> None:
     if out is not None:
         with open(out, 'a+') as fd:
             logger.info(
-                "Writing {} documents' in {} into {}".format(
-                    len(docs), fmt, out))
+                "Writing %d documents in %s into '%s'", len(docs), fmt, out)
             fd.write(outstring)
     else:
         print(outstring)
