@@ -6,8 +6,9 @@ Cli
     :prog: papis mv
 """
 import os
-import subprocess
 import logging
+from typing import Optional
+
 import click
 
 import papis.config
@@ -18,13 +19,12 @@ import papis.cli
 import papis.pick
 import papis.strings
 
-from typing import Optional
-
 
 def run(document: papis.document.Document,
         new_folder_path: str,
         git: bool = False) -> None:
     logger = logging.getLogger('mv:run')
+
     folder = document.get_main_folder()
     if not folder:
         raise Exception(papis.strings.no_folder_attached_to_document)
@@ -32,12 +32,15 @@ def run(document: papis.document.Document,
     cmd += ['mv', folder, new_folder_path]
     db = papis.database.get()
     logger.debug(cmd)
+
+    import subprocess
     subprocess.call(cmd)
     db.delete(document)
     new_document_folder = os.path.join(
         new_folder_path,
         os.path.basename(folder))
-    logger.debug("New document folder: {}".format(new_document_folder))
+    logger.debug("New document folder: '%s'", new_document_folder)
+
     document.set_folder(new_document_folder)
     db.add(document)
 
@@ -92,8 +95,7 @@ def cli(query: str,
                     "Enter directory  : (Tab completion enabled)\n"
                     "Current directory: ({dir})\n".format(
                         dir=document.get_main_folder_name()
-                    ) +
-                    ">  "
+                    ) + ">  "
                 ),
                 completer=completer,
                 complete_while_typing=True
@@ -105,7 +107,7 @@ def cli(query: str,
     logger.info(new_folder)
 
     if not os.path.exists(new_folder):
-        logger.info("Creating path %s" % new_folder)
+        logger.info("Creating path %s", new_folder)
         os.makedirs(new_folder, mode=papis.config.getint('dir-umask') or 0o666)
 
     run(document, new_folder, git=git)
