@@ -1,4 +1,5 @@
 """This command is to update the information of the documents.
+
 Some examples of the usage are given below
 
 Examples
@@ -39,9 +40,10 @@ Cli
     :prog: papis update
 """
 
-import click
-import colorama
 import logging
+from typing import List, Dict, Tuple, Optional, Any
+
+import click
 
 import papis.utils
 import papis.tui.utils
@@ -50,12 +52,11 @@ import papis.downloaders
 import papis.document
 import papis.database
 import papis.pick
+import papis.format
 import papis.cli
 import papis.importer
 import papis.git
 
-from typing import List, Dict, Tuple, Optional, Any
-
 
 def _update_with_database(document: papis.document.Document) -> None:
     document.save()
@@ -94,8 +95,8 @@ def run(document: papis.document.Document,
               is_flag=True)
 @click.option("--from", "from_importer",
               help="Add document from a specific importer ({0})".format(
-                ", ".join(papis.importer.available_importers())
-                ),
+                  ", ".join(papis.importer.available_importers())
+              ),
               type=(click.Choice(papis.importer.available_importers()), str),
               nargs=2,
               multiple=True,
@@ -114,8 +115,7 @@ def cli(query: str,
         sort_field: Optional[str],
         sort_reverse: bool,
         set_tuples: List[Tuple[str, str]],) -> None:
-    """Update a document from a given library"""
-
+    """Update a document from a given library."""
     logger = logging.getLogger('cli:update')
 
     if doc_folder:
@@ -137,13 +137,13 @@ def cli(query: str,
         ctx = papis.importer.Context()
 
         logger.info('Updating '
-                    '{c.Back.WHITE}{c.Fore.BLACK}{0}{c.Style.RESET_ALL}'
-                    .format(papis.document.describe(document), c=colorama))
+                    '{c.Back.WHITE}{c.Fore.BLACK}%s{c.Style.RESET_ALL}',
+                    papis.document.describe(document))
 
         ctx.data.update(document)
         if set_tuples:
             ctx.data.update(
-                {key: papis.document.format_doc(value, document)
+                {key: papis.format.format(value, document)
                     for key, value in set_tuples})
 
         matching_importers = []
@@ -163,7 +163,7 @@ def cli(query: str,
 
         for _importer_name, _uri in from_importer:
             try:
-                _uri = papis.document.format_doc(_uri, document)
+                _uri = papis.format.format(_uri, document)
                 _iclass = papis.importer.get_importer_by_name(_importer_name)
                 importer = _iclass(uri=_uri)
                 importer.fetch()
@@ -174,21 +174,20 @@ def cli(query: str,
 
         if matching_importers:
             logger.info(
-                'There are {0} possible matchings'
-                .format(len(matching_importers)))
+                'There are %d possible matchings', len(matching_importers))
 
             for importer in matching_importers:
                 if importer.ctx.data:
                     logger.info(
-                        'Merging data from importer {0}'.format(importer.name))
+                        "Merging data from importer '%s'", importer.name)
                     papis.utils.update_doc_from_data_interactively(
                         ctx.data,
                         importer.ctx.data,
                         str(importer))
                 if importer.ctx.files:
                     logger.info(
-                        'Got files {0} from importer {1}'
-                        .format(importer.ctx.files, importer.name))
+                        "Got files %s from importer '%s'",
+                        importer.ctx.files, importer.name)
                     for f in importer.ctx.files:
                         papis.utils.open_file(f)
                         if papis.tui.utils.confirm("Use this file?"):
