@@ -1,16 +1,16 @@
-import sys
 import os
-from os.path import expanduser
+import sys
+import logging
 import configparser
+from typing import Dict, Any, List, Optional, Callable  # noqa: ignore
+
 import papis.exceptions
 import papis.library
-import logging
-from typing import Dict, Any, List, Optional, Callable  # noqa: ignore
+
 
 PapisConfigType = Dict[str, Dict[str, Any]]
 
 logger = logging.getLogger("config")
-logger.debug("importing")
 
 _CURRENT_LIBRARY = None  #: Current library in use
 _CONFIGURATION = None  # type: Optional[Configuration]
@@ -48,6 +48,7 @@ general_settings = {
                         or os.environ.get('VISUAL')
                         or get_default_opener(),
     "notes-name": "notes.tex",
+    "notes-template": "",
     "use-cache": True,
     "cache-dir": None,
     "use-git": False,
@@ -76,6 +77,7 @@ general_settings = {
 
     "file-browser": get_default_opener(),
     "bibtex-journal-key": 'journal',
+    "bibtex-export-zotero-file": False,
     "extra-bibtex-keys": "[]",
     "extra-bibtex-types": "[]",
     "default-library": "papers",
@@ -86,12 +88,12 @@ general_settings = {
     "header-format": (
         "<ansired>{doc.html_escape[title]}</ansired>\n"
         " <ansigreen>{doc.html_escape[author]}</ansigreen>\n"
-        "  <blue>({doc.html_escape[year]})</blue> "
+        "  <ansiblue>({doc.html_escape[year]})</ansiblue> "
         "[<ansiyellow>{doc.html_escape[tags]}</ansiyellow>]"
     ),
 
     "info-allow-unicode": True,
-    "ref-format": "{doc[doi]}",
+    "ref-format": "{doc[title]:.15} {doc[author]:.6} {doc[year]}",
     "multiple-authors-separator": " and ",
     "multiple-authors-format": "{au[family]}, {au[given]}",
 
@@ -112,6 +114,23 @@ general_settings = {
     "time-stamp": True,
 
     "document-description-format": '{doc[title]} - {doc[author]}',
+    "formater": "python",
+
+    # fzf options
+    "fzf-binary": "fzf",
+    "fzf-extra-flags": ["--ansi", "--multi", "-i"],
+    "fzf-extra-bindings": ["ctrl-s:jump"],
+    "fzf-header-format": ("{c.Fore.MAGENTA}"
+                          "{doc[title]:<70.70}"
+                          "{c.Style.RESET_ALL}"
+                          " :: "
+                          "{c.Fore.CYAN}"
+                          "{doc[author]:<20.20}"
+                          "{c.Style.RESET_ALL}"
+                          "{c.Fore.YELLOW}"
+                          "«{doc[year]:4}»"
+                          "{c.Style.RESET_ALL}"
+                          ":{doc[tags]}")
 }
 
 
@@ -134,38 +153,37 @@ class Configuration(configparser.ConfigParser):
         self.file_location = get_config_file()
         self.logger = logging.getLogger("Configuration")
         self.default_info = {
-          "papers": {
-            'dir': '~/Documents/papers'
-          },
-          get_general_settings_name(): {
-            'default-library': 'papers'
-          }
+            "papers": {
+                'dir': '~/Documents/papers'
+            },
+            get_general_settings_name(): {
+                'default-library': 'papers'
+            }
         }  # type: PapisConfigType
         self.initialize()
 
     def handle_includes(self) -> None:
         if "include" in self.keys():
             for name in self["include"]:
-                self.logger.debug("including %s" % name)
+                self.logger.debug("Including '%s'", name)
                 fullpath = os.path.expanduser(self.get("include", name))
                 if os.path.exists(fullpath):
                     self.read(fullpath)
                 else:
                     self.logger.warning(
-                        "{0} not included because it does not exist"
-                        .format(fullpath))
+                        "'%s' not included because it does not exist",
+                        fullpath)
 
     def initialize(self) -> None:
         if not os.path.exists(self.dir_location):
             self.logger.warning(
-                'Creating configuration folder in {0}'
-                .format(self.dir_location))
+                "Creating configuration folder in '%s'", self.dir_location)
             os.makedirs(self.dir_location)
         if not os.path.exists(self.scripts_location):
             os.makedirs(self.scripts_location)
         if os.path.exists(self.file_location):
             self.logger.debug(
-                'Reading configuration from {0}'.format(self.file_location))
+                "Reading configuration from '%s'", self.file_location)
             self.read(self.file_location)
             self.handle_includes()
         else:
@@ -174,12 +192,12 @@ class Configuration(configparser.ConfigParser):
                 for field in self.default_info[section]:
                     self[section][field] = self.default_info[section][field]
             with open(self.file_location, "w") as configfile:
-                self.logger.info('Creating config file at {0}'
-                                 .format(self.file_location))
+                self.logger.info(
+                        "Creating config file at '%s'", self.file_location)
                 self.write(configfile)
         configpy = get_configpy_file()
         if os.path.exists(configpy):
-            self.logger.debug('Executing {0}'.format(configpy))
+            self.logger.debug("Executing '%s'", configpy)
             with open(configpy) as fd:
                 exec(fd.read())
 
@@ -243,9 +261,9 @@ def get_config_home() -> str:
     """
     xdg_home = os.environ.get('XDG_CONFIG_HOME')
     if xdg_home:
-        return expanduser(xdg_home)
+        return os.path.expanduser(xdg_home)
     else:
-        return os.path.join(expanduser('~'), '.config')
+        return os.path.join(os.path.expanduser('~'), '.config')
 
 
 def get_config_dirs() -> List[str]:
@@ -262,7 +280,7 @@ def get_config_dirs() -> List[str]:
     # compatibility
     dirs += [
         os.path.join(get_config_home(), 'papis'),
-        os.path.join(expanduser('~'), '.papis')]
+        os.path.join(os.path.expanduser('~'), '.papis')]
     return dirs
 
 
@@ -290,7 +308,7 @@ def get_config_file() -> str:
         config_file = _OVERRIDE_VARS["file"]
     else:
         config_file = os.path.join(get_config_folder(), "config")
-    logger.debug("Getting config file %s" % config_file)
+    logger.debug("Getting config file '%s'", config_file)
     return config_file
 
 
@@ -305,7 +323,7 @@ def set_config_file(filepath: str) -> None:
     """Override the main configuration file path
     """
     global _OVERRIDE_VARS
-    logger.debug("Setting config file to %s" % filepath)
+    logger.debug("Setting config file to '%s'", filepath)
     _OVERRIDE_VARS["file"] = filepath
 
 
@@ -483,7 +501,7 @@ def merge_configuration_from_path(path: Optional[str],
     """
     if path is None or not os.path.exists(path):
         return
-    logger.debug("Merging configuration from " + path)
+    logger.debug("Merging configuration from '%s'", path)
     configuration.read(path)
     configuration.handle_includes()
 
@@ -516,9 +534,9 @@ def get_lib_from_name(libname: str) -> papis.library.Library:
     if libname not in config.keys():
         if os.path.isdir(libname):
             # Check if the path exists, then use this path as a new library
-            logger.warning("Since the path '{0}' exists, "
-                           "I'm interpreting it as a library"
-                           .format(libname))
+            logger.warning(
+                    "Since the path '%s' exists, interpreting it as a library",
+                    libname)
             library_obj = papis.library.from_paths([libname])
             name = library_obj.path_format()
             # the configuration object can only store strings
@@ -527,17 +545,17 @@ def get_lib_from_name(libname: str) -> papis.library.Library:
             raise Exception("Library '{0}' does not seem to exist"
                             "\n\n"
                             "To add a library simply write the following"
-                            "in your configuration file located at '{cpath}'"
+                            " in your configuration file located at '{cpath}'"
                             "\n\n"
                             "\t[{0}]\n"
                             "\tdir = path/to/your/{0}/folder"
                             .format(libname, cpath=get_config_file()))
     else:
         try:
-            paths = [expanduser(config[libname]['dir'])]
+            paths = [os.path.expanduser(config[libname]['dir'])]
         except KeyError:
             try:
-                paths = eval(expanduser(config[libname].get('dirs')))
+                paths = eval(os.path.expanduser(config[libname].get('dirs')))
             except Exception as e:
                 raise Exception("To define a library you have to set either"
                                 " dir or dirs in the configuration file.\n"
@@ -578,8 +596,9 @@ def get_lib() -> papis.library.Library:
     if _CURRENT_LIBRARY is None:
         # Do not put papis.config.get because get is a special function
         # that also needs the library to see if some key was overridden!
-        default_settings = get_default_settings()[get_general_settings_name()]
-        lib = default_settings['default-library']
+        config = papis.config.get_configuration()
+        lib = config.get(papis.config.get_general_settings_name(),
+                         'default-library')
         set_lib_from_name(lib)
     assert(isinstance(_CURRENT_LIBRARY, papis.library.Library))
     return _CURRENT_LIBRARY
