@@ -1,13 +1,17 @@
 import re
+from typing import Optional
+
 import papis.downloaders.base
 
 
-class Downloader(papis.downloaders.base.Downloader):
-    def __init__(self, url):
-        papis.downloaders.base.Downloader.__init__(self, url, name="get")
+class Downloader(papis.downloaders.Downloader):
+
+    def __init__(self, url: str):
+        papis.downloaders.Downloader.__init__(self, url, name="get")
+        self.priority = 0
 
     @classmethod
-    def match(cls, url):
+    def match(cls, url: str) -> Optional[papis.downloaders.Downloader]:
         """
         >>> Downloader.match('http://wha2341!@#!@$%!@#file.pdf') is False
         False
@@ -20,10 +24,12 @@ class Downloader(papis.downloaders.base.Downloader):
         m = re.match(r"^http.*\.(%s)$" % endings, url, re.IGNORECASE)
         if m:
             d = Downloader(url)
-            d.expected_document_extension = m.group(1)
+            extension = m.group(1)
+            d.logger.info("Expecting a document of type '%s'", extension)
+            d.expected_document_extension = extension
             return d
         else:
-            return False
+            return None
 
-    def get_document_url(self):
-        return self.get_url()
+    def get_document_url(self) -> Optional[str]:
+        return self.uri
