@@ -1,15 +1,17 @@
-from itertools import count, product
-from typing import Optional, List, Iterator, Any, Dict, Union
-import copy
-import logging
-import multiprocessing
 import os
+import sys
 import re
-import shlex
-import subprocess
-import time
+import logging
+from itertools import count, product
+from typing import (Optional, List, Iterator, Any, Dict,
+                    Union, Callable, TypeVar)
 
-import colorama
+try:
+    import multiprocessing.synchronize  # noqa: F401
+    from multiprocessing import Pool
+    HAS_MULTIPROCESSING = True
+except ImportError:
+    HAS_MULTIPROCESSING = False
 
 import papis.config
 import papis.exceptions
@@ -18,15 +20,37 @@ import papis.downloaders
 import papis.document
 import papis.database
 
-LOGGER = logging.getLogger("utils")
-LOGGER.debug("importing")
+logger = logging.getLogger("utils")
+
+A = TypeVar("A")
+B = TypeVar("B")
 
 
-def general_open(
-        file_name: str, key: str,
-        default_opener: Optional[str] = None,
-        wait: bool = True) -> None:
-    """Wraper for openers
+def has_multiprocessing() -> bool:
+    return HAS_MULTIPROCESSING
+
+
+def parmap(f: Callable[[A], B],
+           xs: List[A],
+           np: Optional[int] = None) -> List[B]:
+    """
+    todo: enable multiprocessing support for darwin (py3.6+) ...
+    todo: ... see https://github.com/papis/papis/issues/323
+    """
+    if has_multiprocessing() and sys.platform != 'darwin':
+        np = np or os.cpu_count()
+        np = int(os.environ.get("PAPIS_NP", str(np)))
+        with Pool(np) as pool:
+            return list(pool.map(f, xs))
+    else:
+        return list(map(f, xs))
+
+
+def general_open(file_name: str,
+                 key: str,
+                 default_opener: Optional[str] = None,
+                 wait: bool = True) -> None:
+    """Wrapper for openers
     """
     try:
         opener = papis.config.get(key)
@@ -34,13 +58,17 @@ def general_open(
         if default_opener is None:
             default_opener = papis.config.get_default_opener()
         opener = default_opener
+
+    import shlex
     cmd = shlex.split("{0} '{1}'".format(opener, file_name))
-    LOGGER.debug("cmd:  %s", cmd)
+    logger.debug("cmd: %s", cmd)
+
+    import subprocess
     if wait:
-        LOGGER.debug("Waiting for process to finsih")
+        logger.debug("Waiting for process to finish")
         subprocess.call(cmd)
     else:
-        LOGGER.debug("Not waiting for process to finish")
+        logger.debug("Not waiting for process to finish")
         subprocess.Popen(
             cmd, shell=False,
             stdin=None, stdout=None, stderr=None, close_fds=True)
@@ -69,13 +97,16 @@ def get_folders(folder: str) -> List[str]:
     :returns: List of folders containing an info file.
     :rtype: list
     """
-    LOGGER.debug("Indexing folders in '{0}'".format(folder))
-    folders = list()
+    logger.debug("Indexing folders in '%s'", folder)
+
+    folders = []
     for root, dirnames, filenames in os.walk(folder):
         if os.path.exists(
                 os.path.join(root, papis.config.getstring('info-name'))):
             folders.append(root)
-    LOGGER.debug("{0} valid folders retrieved".format(len(folders)))
+
+    logger.debug("%d valid folders retrieved", len(folders))
+
     return folders
 
 
@@ -122,9 +153,9 @@ def clean_document_name(doc_path: str) -> str:
         regex_pattern=regex_pattern))
 
 
-def locate_document_in_lib(
-        document: papis.document.Document,
-        library: Optional[str] = None) -> papis.document.Document:
+def locate_document_in_lib(document: papis.document.Document,
+                           library: Optional[str] = None
+                           ) -> papis.document.Document:
     """Try to figure out if a document is already in a library
 
     :param document: Document to be searched for
@@ -175,23 +206,21 @@ def locate_document(
 
 
 def folders_to_documents(folders: List[str]) -> List[papis.document.Document]:
-    """Turn folders into documents, this is done in a multiprocessing way, this
-    step is quite critical for performance.
+    """Turn folders into documents, this step is quite critical for performance
 
     :param folders: List of folder paths.
     :type  folders: list
     :returns: List of document objects.
     :rtype:  list
+
     """
-    logger = logging.getLogger("utils:dir2doc")
-    np = multiprocessing.cpu_count()
-    logger.debug("converting folder into documents on {0} cores".format(np))
-    pool = multiprocessing.Pool(np)
+    logger = logging.getLogger("utils:folders_to_documents")
+
+    import time
     begin_t = time.time()
-    result = pool.map(papis.document.from_folder, folders)
-    pool.close()
-    pool.join()
-    logger.debug("done in %.1f ms" % (1000*time.time()-1000*begin_t))
+    result = parmap(papis.document.from_folder, folders)
+
+    logger.debug("Done in %.1f ms", 1000*(time.time() - begin_t))
     return result
 
 
@@ -221,22 +250,27 @@ def get_cache_home() -> str:
 
 def get_matching_importer_or_downloader(matching_string: str
                                         ) -> List[papis.importer.Importer]:
-    importers = []  # type: List[papis.importer.Importer]
     logger = logging.getLogger("utils:matcher")
+
+    importers = []  # type: List[papis.importer.Importer]
     _imps = papis.importer.get_importers()
     _downs = papis.downloaders.get_available_downloaders()
     _all_importers = list(_imps) + list(_downs)
     for importer_cls in _all_importers:
         logger.debug("trying with importer "
-                     "{c.Back.BLACK}{c.Fore.YELLOW}{name}{c.Style.RESET_ALL}"
-                     .format(c=colorama, name=importer_cls))
-        importer = importer_cls.match(
-            matching_string)  # type: Optional[papis.importer.Importer]
+                     "{c.Back.BLACK}{c.Fore.YELLOW}%s{c.Style.RESET_ALL}",
+                     importer_cls)
+        try:
+            importer = importer_cls.match(
+                matching_string)  # type: Optional[papis.importer.Importer]
+        except Exception as e:
+            logger.error(e)
+            continue
         if importer:
-            logger.info("{f} {c.Back.BLACK}{c.Fore.GREEN}matches {name}"
-                        "{c.Style.RESET_ALL}".format(f=matching_string,
-                                                     c=colorama,
-                                                     name=importer.name))
+            logger.info(
+                    "%s {c.Back.BLACK}{c.Fore.GREEN}"
+                    "matches %s{c.Style.RESET_ALL}",
+                    matching_string, importer.name)
             try:
                 importer.fetch()
             except Exception as e:
@@ -249,8 +283,10 @@ def get_matching_importer_or_downloader(matching_string: str
 def update_doc_from_data_interactively(
         document: Union[papis.document.Document, Dict[str, Any]],
         data: Dict[str, Any], data_name: str) -> None:
-    import papis.tui.widgets.diff
+    import copy
     docdata = copy.copy(document)
+
+    import papis.tui.widgets.diff
     # do not compare some entries
     docdata.pop('files', None)
     docdata.pop('tags', None)
